@@ -4,7 +4,7 @@ package Dist::Zilla::App::Command::stale;
 # ABSTRACT: print your distribution's prerequisites and plugins that are out of date
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.043';
+our $VERSION = '0.044';
 
 use Dist::Zilla::App -command;
 
@@ -59,8 +59,7 @@ sub stale_modules
 
     return if not @modules;
 
-    require List::MoreUtils;
-    my ($stale_modules, undef) = $plugins[0]->stale_modules(List::MoreUtils::uniq(@modules));
+    my ($stale_modules, undef) = $plugins[0]->stale_modules(uniq(@modules));
     return @$stale_modules;
 }
 
@@ -106,8 +105,7 @@ sub execute
         push @authordeps, $self->_missing_authordeps;
 
         $self->app->chrome->logger->unmute;
-        require List::MoreUtils;
-        $self->log(join("\n", List::MoreUtils::uniq(sort @authordeps)));
+        $self->log(join("\n", uniq(sort @authordeps)));
 
         if (@authordeps)
         {
@@ -148,6 +146,9 @@ sub _missing_authordeps
         };
 }
 
+# until List::Util::uniq exists...
+sub uniq { require List::UtilsBy; unshift @_, sub { $_ }; goto &List::UtilsBy::uniq_by }
+
 1;
 
 __END__
@@ -162,7 +163,7 @@ Dist::Zilla::App::Command::stale - print your distribution's prerequisites and p
 
 =head1 VERSION
 
-version 0.043
+version 0.044
 
 =head1 SYNOPSIS
 
@@ -189,7 +190,7 @@ Checks all plugins and prerequisites (as well as any additional modules listed
 in a local L<[PromptIfStale]|Dist::Zilla::Plugin::PromptIfStale>
 configuration, if there is one).
 
-=for Pod::Coverage stale_modules
+=for Pod::Coverage stale_modules uniq
 
 =head1 SUPPORT
 
