@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.042-8-gb659b36
+package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.043-2-gf577e21
 # ABSTRACT: Check at build/release time if modules are out of date
 # KEYWORDS: prerequisites upstream dependencies modules metadata update stale
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.043';
+our $VERSION = '0.044';
 
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild',
@@ -14,7 +14,7 @@ with 'Dist::Zilla::Role::BeforeBuild',
 
 use Moose::Util::TypeConstraints 'enum';
 use List::Util 1.33 qw(none any);
-use List::MoreUtils 'uniq';
+use List::UtilsBy ();
 use version;
 use Moose::Util 'find_meta';
 use Path::Tiny;
@@ -94,6 +94,9 @@ around dump_config => sub
     return $config;
 };
 
+# until List::Util::uniq exists...
+sub uniq { unshift @_, sub { $_ }; goto &List::UtilsBy::uniq_by }
+
 sub before_build
 {
     my $self = shift;
@@ -449,7 +452,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.043
+version 0.044
 
 =head1 SYNOPSIS
 
@@ -529,7 +532,7 @@ When provided, uses this base URL to fetch F<02packages.details.txt.gz>
 instead of the default C<http://www.cpan.org>.  Use this when your
 distribution uses prerequisites found only in your darkpan-like server.
 
-=for Pod::Coverage mvp_multivalue_args mvp_aliases before_build after_build before_release
+=for Pod::Coverage mvp_multivalue_args mvp_aliases before_build after_build before_release uniq
 
 =head1 METHODS
 
